==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/db.mysql/src/org/netbeans/modules/db/mysql/installations/WindowsStandaloneMultiInstallation.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.db.mysql.installations;

import java.io.File;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import org.netbeans.modules.db.mysql.impl.Installation;
import org.netbeans.modules.db.mysql.impl.MultiInstallation;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileUtil;

/**
 * Class for detection of installed versions of MySQL on Windows OS.
 *
 * @author jhavlin
 */
public class WindowsStandaloneMultiInstallation implements MultiInstallation {

    private static final WindowsStandaloneMultiInstallation DEFAULT =
            new WindowsStandaloneMultiInstallation();
    private Collection<Installation> installations = null;

    @Override
    public Collection<Installation> getInstallations() {
        if (installations != null) {
            return installations;
        }
        FileObject fo = FileUtil.toFileObject(
                new File(WindowsStandaloneInstallation.DEFAULT_BASE_PATH));

        if (fo != null) {
            List<Installation> found = new ArrayList<Installation>(3);
            for (FileObject child : fo.getChildren()) {
                if (child.getNameExt().startsWith(
                        WindowsStandaloneInstallation.FOLDER_NAME_PREFIX)
                        && child.isFolder()) {
                    found.add(
                            new WindowsStandaloneInstallation(
                            child.getNameExt()));
                }
            }
            installations = found;
        } else {
            installations = Collections.emptyList();
        }
        return installations;
    }

    @Override
    public void refresh() {
        installations = null;
    }

    public static WindowsStandaloneMultiInstallation getDefault() {
        return DEFAULT;
    }
}

==> netbeans_8.1+dfsg2.orig.tar.xz: netbeans-8.1/db.mysql/src/org/netbeans/modules/db/mysql/installations/WindowsStandaloneMultiInstallation.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2013 Sun Microsystems, Inc.
 */
package org.netbeans.modules.db.mysql.installations;

import java.io.File;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import org.netbeans.modules.db.mysql.impl.Installation;
import org.netbeans.modules.db.mysql.impl.MultiInstallation;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileUtil;
import org.openide.util.Utilities;

/**
 * Class for detection of installed versions of MySQL on Windows OS.
 *
 * @author jhavlin
 */
public class WindowsStandaloneMultiInstallation implements MultiInstallation {

    private static final WindowsStandaloneMultiInstallation DEFAULT =
            new WindowsStandaloneMultiInstallation();
    private Collection<Installation> installations = null;

    @Override
    public Collection<Installation> getInstallations() {
        if (!Utilities.isWindows()) {
            return Collections.<Installation>emptyList();
        }
        if (installations != null) {
            return installations;
        }
        FileObject fo = FileUtil.toFileObject(
                WindowsStandaloneInstallation.DEFAULT_BASE_PATH);

        if (fo != null) {
            List<Installation> found = new ArrayList<Installation>(3);
            for (FileObject child : fo.getChildren()) {
                if (child.getNameExt().startsWith(
                        WindowsStandaloneInstallation.FOLDER_NAME_PREFIX)
                        && child.isFolder()) {
                    found.add(
                            new WindowsStandaloneInstallation(
                            child.getNameExt()));
                }
            }
            installations = found;
        } else {
            installations = Collections.emptyList();
        }
        return installations;
    }

    @Override
    public void refresh() {
        installations = null;
    }

    public static WindowsStandaloneMultiInstallation getDefault() {
        return DEFAULT;
    }
}
